@@ -31,7 +31,17 @@ class Config:
         "worker": None,
         "language": None,
         "tokenizer": {},
-        "model": {}
+        "model": {},
+        "database": {
+            "dialect": None,
+            "driver": None,
+            "user": None,
+            "password": None,
+            "host": None,
+            "port": None,
+            "database": None,
+            "charset": None
+        }
     }
 
     template_root_status = {
@@ -62,12 +72,15 @@ class Config:
         cls.check_root_directory_exists()
 
         config = cls.load_root_config()
-        print("wikipedia:", config["wikipedia"] or "[not set]")
-        print("worker:", config["worker"] or "[not set]")
-        print("language:", config["language"] or "[not set]")
+        sys.stdout.write("\nRoot Status\n\n")
+        sys.stdout.write(f"wikipedia: {config['wikipedia'] or '[not set]'}\n")
+        sys.stdout.write(f"worker: {config['worker'] or '[not set]'}\n")
+        sys.stdout.write(f"language: {config['language'] or '[not set]'}\n")
+        sys.stdout.write(f"page_chunk: {config['page_chunk']}\n")
+        sys.stdout.write("\n")
 
     @classmethod
-    def command_root_set(cls, wikipedia, worker, language):
+    def command_root_set(cls, wikipedia, worker, language, page_chunk):
         cls.check_root_directory_exists()
 
         config = cls.load_root_config()
@@ -79,17 +92,23 @@ class Config:
             config["wikipedia"] = wikipedia
 
         if worker is not None:
-            if int(worker) not in range(1, 64 + 1):
-                raise WScraperConfigError("Worker should be integer in range from 1 to 64.\n")
+            if not (worker >= Constant.min_worker and worker <= Constant.max_worker):
+                raise WScraperConfigError(f"Worker should be integer in range from {Constant.min_worker} to {Constant.max_worker}.")
 
-            config["worker"] = int(worker)
+            config["worker"] = worker
 
         if language is not None:
             if language not in Constant.available_languages:
-                raise WScraperConfigError(f"language `{language}` is not supported")
+                raise WScraperConfigError(f"language `{language}` is not supported.")
 
             config["language"] = language
 
+        if page_chunk is not None:
+            if not (page_chunk >= Constant.min_page_chunk and page_chunk <= Constant.max_page_chunk):
+                raise WScraperConfigError(f"page_chunk should satisfy {Constant.min_page_chunk} <= page_chunk <= {Constant.max_page_chunk}.")
+
+            config["page_chunk"] = page_chunk
+
         FileManager.save_json(Constant.root_config, config)
 
     @classmethod
@@ -250,24 +269,57 @@ class Config:
         config.set_tokenizer(name)
 
     @classmethod
-    def command_wikipedia(cls):
-        items = cls.list_wikipedia()
-        if len(items) == 0:
-            print("Available Wikipedia is nothing.")
+    def command_list(cls):
+        sys.stdout.write("\n")
+
+        list_task = []
+
+        for path in glob.glob(os.path.join(Constant.task_directory, "*")):
+            if os.path.isdir(path):
+                list_task.append(os.path.basename(path))
+
+        if len(list_task) == 0:
+            sys.stdout.write("Available task is nothing.\n")
         else:
-            print("Available Wikipedia:")
-            for item in items:
-                print(f"  - {item}")
+            sys.stdout.write("Available Task:\n")
+            for item in list_task:
+                sys.stdout.write(f"  - {item}\n")
+
+        sys.stdout.write("\n")
+
+        list_wikipedia = cls.list_wikipedia()
+
+        if len(list_wikipedia) == 0:
+            sys.stdout.write("Available Wikipedia is nothing.\n")
+        else:
+            sys.stdout.write("Available Wikipedia:\n")
+            for item in list_wikipedia:
+                sys.stdout.write(f"  - {item}\n")
+
+        sys.stdout.write("\n")
+
+    @classmethod
+    def command_database_status(cls):
+        cls.check_root_directory_exists()
+
+        Config().print_database_status()
+
+    @classmethod
+    def command_database_set(cls, parameters):
+        cls.check_root_directory_exists()
+
+        config = Config()
+        config.set_database_parameters(parameters)
 
     @classmethod
     def list_wikipedia(cls):
-        result = []
+        items = []
 
         for path in glob.glob(os.path.join(Constant.wikipedia_directory, "*")):
             if os.path.isdir(path):
-                result.append(os.path.basename(path))
+                items.append(os.path.basename(path))
 
-        return result
+        return items
 
     @classmethod
     def load_root_config(cls):
@@ -316,9 +368,9 @@ class Config:
         FileManager.save_json(path, self.config)
 
     def print_status(self):
-        print("current task:", self.name)
+        print("\ncurrent task:", self.name)
 
-        print("")
+        print()
 
         wikipedia = self.config["wikipedia"]
 
@@ -365,6 +417,17 @@ class Config:
                 for k, v in model[key]["arguments"].items():
                     print(f"      {k}: {v}")
 
+        database = self.config["database"]
+
+        if len([v for v in database.values() if v is not None]) == 0:
+            print("database: [not set]")
+        else:
+            print("database:")
+            for key, value in sorted(database.items()):
+                print(f"  {key}: {value}")
+
+        print()
+
     def get_parameter(self, key, *, must = False):
         data = self.config
 
@@ -566,3 +629,36 @@ class Config:
         model_directory = os.path.join(self.this_directory, "model")
         os.makedirs(model_directory, exist_ok = exist_ok)
         return model_directory
+
+    def print_database_status(self):
+        database = self.get_parameter("database", must = True)
+
+        print("current task:", self.name)
+
+        print("")
+        print("database:")
+
+        print("  dialect:", database.get("dialect") or "[not set]")
+        print("  driver:", database.get("driver") or "[not set]")
+        print("  user:", database.get("user") or "[not set]")
+        print("  password:", database.get("password") or "[not set]")
+        print("  host:", database.get("host") or "[not set]")
+        print("  port:", database.get("port") or "[not set]")
+        print("  database:", database.get("database") or "[not set]")
+        print("  charset:", database.get("charset") or "[not set]")
+
+
+    def set_database_parameters(self, parameters):
+        database = self.get_parameter("database", must = True)
+
+        for key, value in parameters.items():
+            if value is None:
+                continue
+
+            before = database.get(key) or "[not set]"
+            after = value
+            database[key] = after
+            sys.stdout.write(f"database config `{key}` changed: `{before}` -> `{after}`\n")
+
+        self.config["database"] = database
+        self.save()
